import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudflareProviderConfig {
    /**
    * Configure API client to always use that account
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#account_id CloudflareProvider#account_id}
    */
    readonly accountId?: string;
    /**
    * Configure the base path used by the API client
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_base_path CloudflareProvider#api_base_path}
    */
    readonly apiBasePath?: string;
    /**
    * Whether to print logs from the API client (using the default log library logger)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_client_logging CloudflareProvider#api_client_logging}
    */
    readonly apiClientLogging?: boolean | cdktf.IResolvable;
    /**
    * Configure the hostname used by the API client
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_hostname CloudflareProvider#api_hostname}
    */
    readonly apiHostname?: string;
    /**
    * The API key for operations.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_key CloudflareProvider#api_key}
    */
    readonly apiKey?: string;
    /**
    * The API Token for operations.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_token CloudflareProvider#api_token}
    */
    readonly apiToken?: string;
    /**
    * A special Cloudflare API key good for a restricted set of endpoints
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#api_user_service_key CloudflareProvider#api_user_service_key}
    */
    readonly apiUserServiceKey?: string;
    /**
    * A registered Cloudflare email address
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#email CloudflareProvider#email}
    */
    readonly email?: string;
    /**
    * Maximum backoff period in seconds after failed API calls
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#max_backoff CloudflareProvider#max_backoff}
    */
    readonly maxBackoff?: number;
    /**
    * Minimum backoff period in seconds after failed API calls
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#min_backoff CloudflareProvider#min_backoff}
    */
    readonly minBackoff?: number;
    /**
    * Maximum number of retries to perform when an API request fails
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#retries CloudflareProvider#retries}
    */
    readonly retries?: number;
    /**
    * RPS limit to apply when making calls to the API
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#rps CloudflareProvider#rps}
    */
    readonly rps?: number;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare#alias CloudflareProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare cloudflare}
*/
export declare class CloudflareProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "cloudflare";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare cloudflare} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudflareProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: CloudflareProviderConfig);
    private _accountId?;
    get accountId(): string | undefined;
    set accountId(value: string | undefined);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _apiBasePath?;
    get apiBasePath(): string | undefined;
    set apiBasePath(value: string | undefined);
    resetApiBasePath(): void;
    get apiBasePathInput(): string | undefined;
    private _apiClientLogging?;
    get apiClientLogging(): boolean | cdktf.IResolvable | undefined;
    set apiClientLogging(value: boolean | cdktf.IResolvable | undefined);
    resetApiClientLogging(): void;
    get apiClientLoggingInput(): boolean | cdktf.IResolvable | undefined;
    private _apiHostname?;
    get apiHostname(): string | undefined;
    set apiHostname(value: string | undefined);
    resetApiHostname(): void;
    get apiHostnameInput(): string | undefined;
    private _apiKey?;
    get apiKey(): string | undefined;
    set apiKey(value: string | undefined);
    resetApiKey(): void;
    get apiKeyInput(): string | undefined;
    private _apiToken?;
    get apiToken(): string | undefined;
    set apiToken(value: string | undefined);
    resetApiToken(): void;
    get apiTokenInput(): string | undefined;
    private _apiUserServiceKey?;
    get apiUserServiceKey(): string | undefined;
    set apiUserServiceKey(value: string | undefined);
    resetApiUserServiceKey(): void;
    get apiUserServiceKeyInput(): string | undefined;
    private _email?;
    get email(): string | undefined;
    set email(value: string | undefined);
    resetEmail(): void;
    get emailInput(): string | undefined;
    private _maxBackoff?;
    get maxBackoff(): number | undefined;
    set maxBackoff(value: number | undefined);
    resetMaxBackoff(): void;
    get maxBackoffInput(): number | undefined;
    private _minBackoff?;
    get minBackoff(): number | undefined;
    set minBackoff(value: number | undefined);
    resetMinBackoff(): void;
    get minBackoffInput(): number | undefined;
    private _retries?;
    get retries(): number | undefined;
    set retries(value: number | undefined);
    resetRetries(): void;
    get retriesInput(): number | undefined;
    private _rps?;
    get rps(): number | undefined;
    set rps(value: number | undefined);
    resetRps(): void;
    get rpsInput(): number | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=cloudflare-provider.d.ts.map